stupid_simple_sheet library

Classes

AbsoluteSnapPhysics
A SnapPhysics implementation that needs the current sheet height to calculate the target snap point based on absolute position and velocity.
CupertinoMotion
A collection of spring motions that are commonly used in Cupertino apps.
CurvedMotion
A motion based on a fixed duration and curve.
FlingSnapPhysics
A simple SnapPhysics implementation that discerns between a fling and a drag based on velocity, and if it's a fling, projects the position forward to the next snap point in the direction of the fling.
FrictionSnapPhysics
A SnapPhysics implementation that uses a FrictionSimulation to predict the natural settling point based on the current velocity and position, and then finds the closest snap point to that projected position.
LinearMotion
A convenience class for a CurvedMotion that uses a linear curve.
MaterialSpringMotion
Material Design 3 spring motion tokens for expressive design system.
Motion
A motion pattern such as spring physics or duration-based curves.
MotionCurve
A Curve that is represented by a Motion.
NoMotion
A motion that holds at the current value for duration and never reaches its target.
RelativeSnapPhysics
A SnapPhysics implementation that calculates the target snap point based on normalized position and velocity, without needing the current sheet height.
RenderShrinkTransition
Render object that lays out its child at a height determined by sizeFactor, falling back to the child's minimum intrinsic height when the target height is too small.
SheetBackground
A widget that provides a background for a sheet, including shape and color.
SheetDismissalTransition
A widget that animates its child based on a DismissalMode and an Animation<double>.
SheetSnappingConfig
Configuration for sheet snapping behavior.
ShrinkTransition
A widget that shrinks its child vertically based on sizeFactor.
SnapPhysics
Provides heuristics for finding a target snap point based on drag velocity and position.
SpringMotion
A motion based on spring physics.
StupidSimpleCupertinoSheetRoute<T>
Simular to CupertinoSheetRoute but with the drag gesture improvements from this package.
StupidSimpleGlassSheetRoute<T>
A sheet route styled after the iOS 26 liquid glass aesthetic.
StupidSimpleSheetRoute<T>
A modal route that displays a sheet that slides up from the bottom.
TrimmedMotion
A motion that uses only a portion of another motion's characteristic curve.

Enums

DismissalMode
The mode used to animate the sheet's dismissal.
RouteSnapshotMode
Controls when the route behind the sheet is rasterized to a GPU texture instead of being painted live.

Mixins

StupidSimpleSheetController<T>
A mixin that provides imperative control over a sheet's animation.
StupidSimpleSheetTransitionMixin<T>
A mixin that provides sheet transition behavior for a PopupRoute.

Extensions

CurveConversion on Motion
Converts a Motion to a MotionCurve.
MotionTrimming on Motion
Extension methods for Motion to provide convenient trimming functionality.